# status
Retrieve docker container status

# Python
```bash
pip3 install tgbot_ping
```

For some unknown reasons(maybe docker bug), sometime it will fail to get CPU usage. Restart container will fix it.
